Skip site navigation (1)Skip section navigation (2)
Date:      Sun, 24 Dec 2017 01:04:59 +0000 (UTC)
From:      Dimitry Andric <dim@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-projects@freebsd.org
Subject:   svn commit: r327134 - in projects/clang600-import/contrib/llvm: include/llvm include/llvm-c include/llvm/Analysis include/llvm/BinaryFormat include/llvm/BinaryFormat/WasmRelocs include/llvm/CodeGen...
Message-ID:  <201712240104.vBO14xC8078238@repo.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: dim
Date: Sun Dec 24 01:04:58 2017
New Revision: 327134
URL: https://svnweb.freebsd.org/changeset/base/327134

Log:
  Merge llvm trunk r321414 to contrib/llvm.

Added:
  projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/WasmRelocs.def
     - copied unchanged from r327133, vendor/llvm/dist/include/llvm/BinaryFormat/WasmRelocs.def
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/LiveStacks.h
     - copied unchanged from r327133, vendor/llvm/dist/include/llvm/CodeGen/LiveStacks.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SDNodeProperties.td
     - copied unchanged from r327133, vendor/llvm/dist/include/llvm/CodeGen/SDNodeProperties.td
  projects/clang600-import/contrib/llvm/lib/CodeGen/LiveStacks.cpp
     - copied unchanged from r327133, vendor/llvm/dist/lib/CodeGen/LiveStacks.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/SDNodeProperties.cpp
     - copied unchanged from r327133, vendor/llvm/dist/utils/TableGen/SDNodeProperties.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/SDNodeProperties.h
     - copied unchanged from r327133, vendor/llvm/dist/utils/TableGen/SDNodeProperties.h
Deleted:
  projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/WasmRelocs/WebAssembly.def
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/LiveStackAnalysis.h
  projects/clang600-import/contrib/llvm/lib/CodeGen/LiveStackAnalysis.cpp
Modified:
  projects/clang600-import/contrib/llvm/include/llvm-c/lto.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysis.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysisEvaluator.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/LoopAccessAnalysis.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/MemoryDependenceAnalysis.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/ProfileSummaryInfo.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/ScalarEvolutionExpander.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfo.h
  projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfoImpl.h
  projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/Wasm.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/BasicTTIImpl.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelector.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelectorImpl.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/MachineOperand.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/RuntimeLibcalls.def
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SelectionDAGNodes.h
  projects/clang600-import/contrib/llvm/include/llvm/CodeGen/TargetLowering.h
  projects/clang600-import/contrib/llvm/include/llvm/DebugInfo/DWARF/DWARFUnit.h
  projects/clang600-import/contrib/llvm/include/llvm/FuzzMutate/IRMutator.h
  projects/clang600-import/contrib/llvm/include/llvm/IR/Function.h
  projects/clang600-import/contrib/llvm/include/llvm/IR/Intrinsics.td
  projects/clang600-import/contrib/llvm/include/llvm/LTO/legacy/ThinLTOCodeGenerator.h
  projects/clang600-import/contrib/llvm/include/llvm/MC/MCAsmInfo.h
  projects/clang600-import/contrib/llvm/include/llvm/MC/MCStreamer.h
  projects/clang600-import/contrib/llvm/include/llvm/Object/Wasm.h
  projects/clang600-import/contrib/llvm/include/llvm/Support/CachePruning.h
  projects/clang600-import/contrib/llvm/include/llvm/Support/MemoryBuffer.h
  projects/clang600-import/contrib/llvm/include/llvm/Support/YAMLTraits.h
  projects/clang600-import/contrib/llvm/include/llvm/Target/TargetMachine.h
  projects/clang600-import/contrib/llvm/include/llvm/Target/TargetSelectionDAG.td
  projects/clang600-import/contrib/llvm/include/llvm/Transforms/Instrumentation.h
  projects/clang600-import/contrib/llvm/include/llvm/Transforms/Utils/CallPromotionUtils.h
  projects/clang600-import/contrib/llvm/include/llvm/module.modulemap
  projects/clang600-import/contrib/llvm/lib/Analysis/AliasAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/AliasAnalysisEvaluator.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/BasicAliasAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/CFGPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/GlobalsModRef.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/InlineCost.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/LoopAccessAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/MemoryDependenceAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/MemorySSA.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/ModuleSummaryAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/ProfileSummaryInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/ScalarEvolution.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/TargetTransformInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Analysis/TypeBasedAliasAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/Bitcode/Writer/BitcodeWriter.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/AsmPrinter/AsmPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/CodeGenPrepare.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/GlobalISel/LegalizerHelper.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/InlineSpiller.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/LLVMTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/MIRPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/MachineBlockPlacement.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/MachineOperand.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/MachineVerifier.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/RegAllocBasic.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/RegAllocGreedy.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/RegAllocPBQP.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/DAGCombiner.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/LegalizeFloatTypes.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/LegalizeTypes.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/LegalizeVectorTypes.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/ResourcePriorityQueue.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/SelectionDAGAddressAnalysis.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/SelectionDAG/TargetLowering.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/StackSlotColoring.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/TargetLoweringBase.cpp
  projects/clang600-import/contrib/llvm/lib/CodeGen/VirtRegMap.cpp
  projects/clang600-import/contrib/llvm/lib/DebugInfo/DWARF/DWARFAcceleratorTable.cpp
  projects/clang600-import/contrib/llvm/lib/DebugInfo/DWARF/DWARFContext.cpp
  projects/clang600-import/contrib/llvm/lib/DebugInfo/DWARF/DWARFUnit.cpp
  projects/clang600-import/contrib/llvm/lib/Demangle/ItaniumDemangle.cpp
  projects/clang600-import/contrib/llvm/lib/FuzzMutate/IRMutator.cpp
  projects/clang600-import/contrib/llvm/lib/IR/ConstantFold.cpp
  projects/clang600-import/contrib/llvm/lib/IR/Function.cpp
  projects/clang600-import/contrib/llvm/lib/IR/Value.cpp
  projects/clang600-import/contrib/llvm/lib/MC/MCAsmStreamer.cpp
  projects/clang600-import/contrib/llvm/lib/MC/MCStreamer.cpp
  projects/clang600-import/contrib/llvm/lib/MC/WasmObjectWriter.cpp
  projects/clang600-import/contrib/llvm/lib/Object/ELF.cpp
  projects/clang600-import/contrib/llvm/lib/Object/WasmObjectFile.cpp
  projects/clang600-import/contrib/llvm/lib/Object/WindowsResource.cpp
  projects/clang600-import/contrib/llvm/lib/ObjectYAML/WasmYAML.cpp
  projects/clang600-import/contrib/llvm/lib/Support/APFloat.cpp
  projects/clang600-import/contrib/llvm/lib/Support/CachePruning.cpp
  projects/clang600-import/contrib/llvm/lib/Support/MemoryBuffer.cpp
  projects/clang600-import/contrib/llvm/lib/Support/StringRef.cpp
  projects/clang600-import/contrib/llvm/lib/Support/TargetParser.cpp
  projects/clang600-import/contrib/llvm/lib/Support/YAMLTraits.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64AsmPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64FastISel.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64FrameLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64ISelLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64InstrInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64SelectionDAGInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64Subtarget.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64Subtarget.h
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64SystemOperands.td
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64TargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AArch64TargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/AArch64/AsmParser/AArch64AsmParser.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/AMDGPUAsmPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/AMDGPUISelLowering.h
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/AMDGPUTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/AsmParser/AMDGPUAsmParser.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/Disassembler/AMDGPUDisassembler.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/Disassembler/AMDGPUDisassembler.h
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/InstPrinter/AMDGPUInstPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/SIRegisterInfo.td
  projects/clang600-import/contrib/llvm/lib/Target/AMDGPU/Utils/AMDGPUBaseInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARC/ARCTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARC/ARCTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARM.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARM.td
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMFastISel.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMISelLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMISelLowering.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMInstrInfo.td
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMInstrThumb2.td
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMInstructionSelector.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMLegalizerInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMRegisterBankInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMSubtarget.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMSubtarget.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMTargetTransformInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/ARMTargetTransformInfo.h
  projects/clang600-import/contrib/llvm/lib/Target/ARM/AsmParser/ARMAsmParser.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/Disassembler/ARMDisassembler.cpp
  projects/clang600-import/contrib/llvm/lib/Target/ARM/Thumb2SizeReduction.cpp
  projects/clang600-import/contrib/llvm/lib/Target/BPF/InstPrinter/BPFInstPrinter.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonISelDAGToDAGHVX.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonISelLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonISelLowering.h
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonISelLoweringHVX.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonPatterns.td
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonRegisterInfo.td
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonSubtarget.h
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Hexagon/HexagonTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/Lanai/LanaiTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Lanai/LanaiTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/Mips/MCTargetDesc/MipsMCCodeEmitter.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Mips/MipsRegisterInfo.td
  projects/clang600-import/contrib/llvm/lib/Target/Mips/MipsTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/Mips/MipsTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/NVPTX/NVPTXTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/NVPTX/NVPTXTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/PowerPC/PPCFrameLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/PowerPC/PPCISelLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/PowerPC/PPCMIPeephole.cpp
  projects/clang600-import/contrib/llvm/lib/Target/PowerPC/PPCTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/PowerPC/PPCTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/SystemZ/SystemZTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/SystemZ/SystemZTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/TargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/WebAssembly/WebAssemblyRegStackify.cpp
  projects/clang600-import/contrib/llvm/lib/Target/WebAssembly/WebAssemblyRuntimeLibcallSignatures.cpp
  projects/clang600-import/contrib/llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/WebAssembly/WebAssemblyTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/X86/MCTargetDesc/X86AsmBackend.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86.td
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86DomainReassignment.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86ISelDAGToDAG.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86ISelLowering.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86Instr3DNow.td
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86InstrFormats.td
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86InstrInfo.td
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86InstrSSE.td
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86SelectionDAGInfo.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86Subtarget.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86Subtarget.h
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86TargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/X86/X86TargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Target/XCore/XCoreTargetMachine.cpp
  projects/clang600-import/contrib/llvm/lib/Target/XCore/XCoreTargetMachine.h
  projects/clang600-import/contrib/llvm/lib/Transforms/IPO/PartialInlining.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/IPO/SampleProfile.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/IPO/WholeProgramDevirt.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/InstCombine/InstCombineCalls.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Instrumentation/HWAddressSanitizer.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/CallSiteSplitting.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/JumpThreading.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/LoopSink.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/LoopUnrollPass.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/MemCpyOptimizer.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/SCCP.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Scalar/SeparateConstOffsetFromGEP.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Utils/CallPromotionUtils.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Utils/LoopUnrollPeel.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Utils/SimplifyCFG.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Vectorize/LoopVectorize.cpp
  projects/clang600-import/contrib/llvm/lib/Transforms/Vectorize/SLPVectorizer.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-dwarfdump/llvm-dwarfdump.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-lto/llvm-lto.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-objcopy/Object.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-objcopy/Object.h
  projects/clang600-import/contrib/llvm/tools/llvm-objcopy/llvm-objcopy.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-readobj/ELFDumper.cpp
  projects/clang600-import/contrib/llvm/tools/llvm-readobj/WasmDumper.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/CodeGenDAGPatterns.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/CodeGenDAGPatterns.h
  projects/clang600-import/contrib/llvm/utils/TableGen/CodeGenIntrinsics.h
  projects/clang600-import/contrib/llvm/utils/TableGen/CodeGenTarget.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/CodeGenTarget.h
  projects/clang600-import/contrib/llvm/utils/TableGen/GlobalISelEmitter.cpp
  projects/clang600-import/contrib/llvm/utils/TableGen/IntrinsicEmitter.cpp
Directory Properties:
  projects/clang600-import/contrib/llvm/   (props changed)

Modified: projects/clang600-import/contrib/llvm/include/llvm-c/lto.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm-c/lto.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm-c/lto.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -757,17 +757,17 @@ extern void thinlto_codegen_add_cross_referenced_symbo
  * @ingroup LLVMCTLTO
  *
  * These entry points control the ThinLTO cache. The cache is intended to
- * support incremental build, and thus needs to be persistent accross build.
- * The client enabled the cache by supplying a path to an existing directory.
+ * support incremental builds, and thus needs to be persistent across builds.
+ * The client enables the cache by supplying a path to an existing directory.
  * The code generator will use this to store objects files that may be reused
  * during a subsequent build.
  * To avoid filling the disk space, a few knobs are provided:
- *  - The pruning interval limit the frequency at which the garbage collector
- *    will try to scan the cache directory to prune it from expired entries.
- *    Setting to -1 disable the pruning (default).
+ *  - The pruning interval limits the frequency at which the garbage collector
+ *    will try to scan the cache directory to prune expired entries.
+ *    Setting to a negative number disables the pruning.
  *  - The pruning expiration time indicates to the garbage collector how old an
  *    entry needs to be to be removed.
- *  - Finally, the garbage collector can be instructed to prune the cache till
+ *  - Finally, the garbage collector can be instructed to prune the cache until
  *    the occupied space goes below a threshold.
  * @{
  */
@@ -782,7 +782,7 @@ extern void thinlto_codegen_set_cache_dir(thinlto_code
                                           const char *cache_dir);
 
 /**
- * Sets the cache pruning interval (in seconds). A negative value disable the
+ * Sets the cache pruning interval (in seconds). A negative value disables the
  * pruning. An unspecified default value will be applied, and a value of 0 will
  * be ignored.
  *

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysis.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysisEvaluator.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysisEvaluator.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -35,19 +35,23 @@ class AAEvaluator : public PassInfoMixin<AAEvaluator> 
   int64_t FunctionCount;
   int64_t NoAliasCount, MayAliasCount, PartialAliasCount, MustAliasCount;
   int64_t NoModRefCount, ModCount, RefCount, ModRefCount;
+  int64_t MustCount, MustRefCount, MustModCount, MustModRefCount;
 
 public:
   AAEvaluator()
       : FunctionCount(), NoAliasCount(), MayAliasCount(), PartialAliasCount(),
         MustAliasCount(), NoModRefCount(), ModCount(), RefCount(),
-        ModRefCount() {}
+        ModRefCount(), MustCount(), MustRefCount(), MustModCount(),
+        MustModRefCount() {}
   AAEvaluator(AAEvaluator &&Arg)
       : FunctionCount(Arg.FunctionCount), NoAliasCount(Arg.NoAliasCount),
         MayAliasCount(Arg.MayAliasCount),
         PartialAliasCount(Arg.PartialAliasCount),
         MustAliasCount(Arg.MustAliasCount), NoModRefCount(Arg.NoModRefCount),
         ModCount(Arg.ModCount), RefCount(Arg.RefCount),
-        ModRefCount(Arg.ModRefCount) {
+        ModRefCount(Arg.ModRefCount), MustCount(Arg.MustCount),
+        MustRefCount(Arg.MustRefCount), MustModCount(Arg.MustModCount),
+        MustModRefCount(Arg.MustModRefCount) {
     Arg.FunctionCount = 0;
   }
   ~AAEvaluator();

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/LoopAccessAnalysis.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/LoopAccessAnalysis.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/LoopAccessAnalysis.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -667,21 +667,6 @@ int64_t getPtrStride(PredicatedScalarEvolution &PSE, V
                      const ValueToValueMap &StridesMap = ValueToValueMap(),
                      bool Assume = false, bool ShouldCheckWrap = true);
 
-/// \brief Attempt to sort the 'loads' in \p VL and return the sorted values in
-/// \p Sorted.
-///
-/// Returns 'false' if sorting is not legal or feasible, otherwise returns
-/// 'true'. If \p Mask is not null, it also returns the \p Mask which is the
-/// shuffle mask for actual memory access order.
-///
-/// For example, for a given VL of memory accesses in program order, a[i+2],
-/// a[i+0], a[i+1] and a[i+3], this function will sort the VL and save the
-/// sorted value in 'Sorted' as a[i+0], a[i+1], a[i+2], a[i+3] and saves the
-/// mask for actual memory accesses in program order in 'Mask' as <2,0,1,3>
-bool sortLoadAccesses(ArrayRef<Value *> VL, const DataLayout &DL,
-    ScalarEvolution &SE, SmallVectorImpl<Value *> &Sorted,
-    SmallVectorImpl<unsigned> *Mask = nullptr);
-
 /// \brief Returns true if the memory operations \p A and \p B are consecutive.
 /// This is a simple API that does not depend on the analysis pass. 
 bool isConsecutiveAccess(Value *A, Value *B, const DataLayout &DL,

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/MemoryDependenceAnalysis.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/MemoryDependenceAnalysis.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/MemoryDependenceAnalysis.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -407,6 +407,12 @@ class MemoryDependenceResults { (public)
   void getNonLocalPointerDependency(Instruction *QueryInst,
                                     SmallVectorImpl<NonLocalDepResult> &Result);
 
+  /// Perform a dependency query specifically for QueryInst's access to Loc.
+  /// The other comments for getNonLocalPointerDependency apply here as well.
+  void getNonLocalPointerDependencyFrom(Instruction *QueryInst,
+                                        const MemoryLocation &Loc, bool isLoad,
+                                        SmallVectorImpl<NonLocalDepResult> &Result);
+
   /// Removes an instruction from the dependence analysis, updating the
   /// dependence of instructions that previously depended on it.
   void removeInstruction(Instruction *InstToRemove);

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/ProfileSummaryInfo.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/ProfileSummaryInfo.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/ProfileSummaryInfo.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -92,12 +92,12 @@ class ProfileSummaryInfo { (public)
   bool hasHugeWorkingSetSize();
   /// \brief Returns true if \p F has hot function entry.
   bool isFunctionEntryHot(const Function *F);
-  /// Returns true if \p F has hot function entry or hot call edge.
-  bool isFunctionHotInCallGraph(const Function *F);
+  /// Returns true if \p F contains hot code.
+  bool isFunctionHotInCallGraph(const Function *F, BlockFrequencyInfo &BFI);
   /// \brief Returns true if \p F has cold function entry.
   bool isFunctionEntryCold(const Function *F);
-  /// Returns true if \p F has cold function entry or cold call edge.
-  bool isFunctionColdInCallGraph(const Function *F);
+  /// Returns true if \p F contains only cold code.
+  bool isFunctionColdInCallGraph(const Function *F, BlockFrequencyInfo &BFI);
   /// \brief Returns true if \p F is a hot function.
   bool isHotCount(uint64_t C);
   /// \brief Returns true if count \p C is considered cold.

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/ScalarEvolutionExpander.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/ScalarEvolutionExpander.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/ScalarEvolutionExpander.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -47,7 +47,7 @@ namespace llvm {
     ScalarEvolution &SE;
     const DataLayout &DL;
 
-    // New instructions receive a name to identifies them with the current pass.
+    // New instructions receive a name to identify them with the current pass.
     const char* IVName;
 
     // InsertedExpressions caches Values for reuse, so must track RAUW.

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfo.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfo.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfo.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -646,6 +646,9 @@ class TargetTransformInfo { (public)
   /// \brief Additional properties of an operand's values.
   enum OperandValueProperties { OP_None = 0, OP_PowerOf2 = 1 };
 
+  /// \return True if target can execute instructions out of order.
+  bool isOutOfOrder() const;
+
   /// \return The number of scalar or vector registers that the target has.
   /// If 'Vectors' is true, it returns the number of vector registers. If it is
   /// set to false, it returns the number of scalar registers.
@@ -1018,6 +1021,7 @@ class TargetTransformInfo::Concept { (public)
                             Type *Ty) = 0;
   virtual int getIntImmCost(Intrinsic::ID IID, unsigned Idx, const APInt &Imm,
                             Type *Ty) = 0;
+  virtual bool isOutOfOrder() const = 0;
   virtual unsigned getNumberOfRegisters(bool Vector) = 0;
   virtual unsigned getRegisterBitWidth(bool Vector) const = 0;
   virtual unsigned getMinVectorRegisterBitWidth() = 0;
@@ -1294,6 +1298,9 @@ class TargetTransformInfo::Model final : public Target
   int getIntImmCost(Intrinsic::ID IID, unsigned Idx, const APInt &Imm,
                     Type *Ty) override {
     return Impl.getIntImmCost(IID, Idx, Imm, Ty);
+  }
+  bool isOutOfOrder() const override {
+    return Impl.isOutOfOrder();
   }
   unsigned getNumberOfRegisters(bool Vector) override {
     return Impl.getNumberOfRegisters(Vector);

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfoImpl.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfoImpl.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/TargetTransformInfoImpl.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -337,6 +337,8 @@ class TargetTransformInfoImplBase { (public)
     return TTI::TCC_Free;
   }
 
+  bool isOutOfOrder() const { return false; }
+
   unsigned getNumberOfRegisters(bool Vector) { return 8; }
 
   unsigned getRegisterBitWidth(bool Vector) const { return 32; }

Modified: projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/Wasm.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/Wasm.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/Wasm.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -208,7 +208,7 @@ const unsigned WASM_SYMBOL_VISIBILITY_HIDDEN  = 0x4;
 #define WASM_RELOC(name, value) name = value,
 
 enum : unsigned {
-#include "WasmRelocs/WebAssembly.def"
+#include "WasmRelocs.def"
 };
 
 #undef WASM_RELOC

Copied: projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/WasmRelocs.def (from r327133, vendor/llvm/dist/include/llvm/BinaryFormat/WasmRelocs.def)
==============================================================================
--- /dev/null	00:00:00 1970	(empty, because file is newly added)
+++ projects/clang600-import/contrib/llvm/include/llvm/BinaryFormat/WasmRelocs.def	Sun Dec 24 01:04:58 2017	(r327134, copy of r327133, vendor/llvm/dist/include/llvm/BinaryFormat/WasmRelocs.def)
@@ -0,0 +1,13 @@
+
+#ifndef WASM_RELOC
+#error "WASM_RELOC must be defined"
+#endif
+
+WASM_RELOC(R_WEBASSEMBLY_FUNCTION_INDEX_LEB,   0)
+WASM_RELOC(R_WEBASSEMBLY_TABLE_INDEX_SLEB,     1)
+WASM_RELOC(R_WEBASSEMBLY_TABLE_INDEX_I32,      2)
+WASM_RELOC(R_WEBASSEMBLY_MEMORY_ADDR_LEB,      3)
+WASM_RELOC(R_WEBASSEMBLY_MEMORY_ADDR_SLEB,     4)
+WASM_RELOC(R_WEBASSEMBLY_MEMORY_ADDR_I32,      5)
+WASM_RELOC(R_WEBASSEMBLY_TYPE_INDEX_LEB,       6)
+WASM_RELOC(R_WEBASSEMBLY_GLOBAL_INDEX_LEB,     7)

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/BasicTTIImpl.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/BasicTTIImpl.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/BasicTTIImpl.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -302,9 +302,13 @@ class BasicTTIImplBase : public TargetTransformInfoImp
   }
 
   unsigned getFPOpCost(Type *Ty) {
-    // By default, FP instructions are no more expensive since they are
-    // implemented in HW.  Target specific TTI can override this.
-    return TargetTransformInfo::TCC_Basic;
+    // Check whether FADD is available, as a proxy for floating-point in
+    // general.
+    const TargetLoweringBase *TLI = getTLI();
+    EVT VT = TLI->getValueType(DL, Ty);
+    if (TLI->isOperationLegalOrCustomOrPromote(ISD::FADD, VT))
+      return TargetTransformInfo::TCC_Basic;
+    return TargetTransformInfo::TCC_Expensive;
   }
 
   unsigned getOperationCost(unsigned Opcode, Type *Ty, Type *OpTy) {
@@ -396,6 +400,10 @@ class BasicTTIImplBase : public TargetTransformInfoImp
       return getST()->getSchedModel().DefaultLoadLatency;
 
     return BaseT::getInstructionLatency(I);
+  }
+
+  bool isOutOfOrder() const {
+    return getST()->getSchedModel().isOutOfOrder();
   }
 
   /// @}

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelector.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelector.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelector.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -282,10 +282,6 @@ enum {
 /// Provides the logic to select generic machine instructions.
 class InstructionSelector {
 public:
-  using I64ImmediatePredicateFn = bool (*)(int64_t);
-  using APIntImmediatePredicateFn = bool (*)(const APInt &);
-  using APFloatImmediatePredicateFn = bool (*)(const APFloat &);
-
   virtual ~InstructionSelector() = default;
 
   /// Select the (possibly generic) instruction \p I to only use target-specific
@@ -319,9 +315,6 @@ class InstructionSelector { (public)
   struct MatcherInfoTy {
     const LLT *TypeObjects;
     const PredicateBitset *FeatureBitsets;
-    const I64ImmediatePredicateFn *I64ImmPredicateFns;
-    const APIntImmediatePredicateFn *APIntImmPredicateFns;
-    const APFloatImmediatePredicateFn *APFloatImmPredicateFns;
     const ComplexMatcherMemFn *ComplexPredicates;
   };
 
@@ -339,6 +332,16 @@ class InstructionSelector { (public)
       MachineRegisterInfo &MRI, const TargetRegisterInfo &TRI,
       const RegisterBankInfo &RBI, const PredicateBitset &AvailableFeatures,
       CodeGenCoverage &CoverageInfo) const;
+
+  virtual bool testImmPredicate_I64(unsigned, int64_t) const {
+    llvm_unreachable("Subclasses must override this to use tablegen");
+  }
+  virtual bool testImmPredicate_APInt(unsigned, const APInt &) const {
+    llvm_unreachable("Subclasses must override this to use tablegen");
+  }
+  virtual bool testImmPredicate_APFloat(unsigned, const APFloat &) const {
+    llvm_unreachable("Subclasses must override this to use tablegen");
+  }
 
   /// Constrain a register operand of an instruction \p I to a specified
   /// register class. This could involve inserting COPYs before (for uses) or

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelectorImpl.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelectorImpl.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/GlobalISel/InstructionSelectorImpl.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -181,7 +181,7 @@ bool InstructionSelector::executeMatchTable(
       else
         llvm_unreachable("Expected Imm or CImm operand");
 
-      if (!MatcherInfo.I64ImmPredicateFns[Predicate](Value))
+      if (!testImmPredicate_I64(Predicate, Value))
         if (handleReject() == RejectAndGiveUp)
           return false;
       break;
@@ -202,7 +202,7 @@ bool InstructionSelector::executeMatchTable(
       else
         llvm_unreachable("Expected Imm or CImm operand");
 
-      if (!MatcherInfo.APIntImmPredicateFns[Predicate](Value))
+      if (!testImmPredicate_APInt(Predicate, Value))
         if (handleReject() == RejectAndGiveUp)
           return false;
       break;
@@ -221,7 +221,7 @@ bool InstructionSelector::executeMatchTable(
       assert(Predicate > GIPFP_APFloat_Invalid && "Expected a valid predicate");
       APFloat Value = State.MIs[InsnID]->getOperand(1).getFPImm()->getValueAPF();
 
-      if (!MatcherInfo.APFloatImmPredicateFns[Predicate](Value))
+      if (!testImmPredicate_APFloat(Predicate, Value))
         if (handleReject() == RejectAndGiveUp)
           return false;
       break;

Copied: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/LiveStacks.h (from r327133, vendor/llvm/dist/include/llvm/CodeGen/LiveStacks.h)
==============================================================================
--- /dev/null	00:00:00 1970	(empty, because file is newly added)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/LiveStacks.h	Sun Dec 24 01:04:58 2017	(r327134, copy of r327133, vendor/llvm/dist/include/llvm/CodeGen/LiveStacks.h)
@@ -0,0 +1,103 @@
+//===- LiveStacks.h - Live Stack Slot Analysis ------------------*- C++ -*-===//
+//
+//                     The LLVM Compiler Infrastructure
+//
+// This file is distributed under the University of Illinois Open Source
+// License. See LICENSE.TXT for details.
+//
+//===----------------------------------------------------------------------===//
+//
+// This file implements the live stack slot analysis pass. It is analogous to
+// live interval analysis except it's analyzing liveness of stack slots rather
+// than registers.
+//
+//===----------------------------------------------------------------------===//
+
+#ifndef LLVM_CODEGEN_LIVESTACKS_H
+#define LLVM_CODEGEN_LIVESTACKS_H
+
+#include "llvm/CodeGen/LiveInterval.h"
+#include "llvm/CodeGen/MachineFunctionPass.h"
+#include "llvm/Pass.h"
+#include <cassert>
+#include <map>
+#include <unordered_map>
+
+namespace llvm {
+
+class TargetRegisterClass;
+class TargetRegisterInfo;
+
+class LiveStacks : public MachineFunctionPass {
+  const TargetRegisterInfo *TRI;
+
+  /// Special pool allocator for VNInfo's (LiveInterval val#).
+  ///
+  VNInfo::Allocator VNInfoAllocator;
+
+  /// S2IMap - Stack slot indices to live interval mapping.
+  using SS2IntervalMap = std::unordered_map<int, LiveInterval>;
+  SS2IntervalMap S2IMap;
+
+  /// S2RCMap - Stack slot indices to register class mapping.
+  std::map<int, const TargetRegisterClass *> S2RCMap;
+
+public:
+  static char ID; // Pass identification, replacement for typeid
+
+  LiveStacks() : MachineFunctionPass(ID) {
+    initializeLiveStacksPass(*PassRegistry::getPassRegistry());
+  }
+
+  using iterator = SS2IntervalMap::iterator;
+  using const_iterator = SS2IntervalMap::const_iterator;
+
+  const_iterator begin() const { return S2IMap.begin(); }
+  const_iterator end() const { return S2IMap.end(); }
+  iterator begin() { return S2IMap.begin(); }
+  iterator end() { return S2IMap.end(); }
+
+  unsigned getNumIntervals() const { return (unsigned)S2IMap.size(); }
+
+  LiveInterval &getOrCreateInterval(int Slot, const TargetRegisterClass *RC);
+
+  LiveInterval &getInterval(int Slot) {
+    assert(Slot >= 0 && "Spill slot indice must be >= 0");
+    SS2IntervalMap::iterator I = S2IMap.find(Slot);
+    assert(I != S2IMap.end() && "Interval does not exist for stack slot");
+    return I->second;
+  }
+
+  const LiveInterval &getInterval(int Slot) const {
+    assert(Slot >= 0 && "Spill slot indice must be >= 0");
+    SS2IntervalMap::const_iterator I = S2IMap.find(Slot);
+    assert(I != S2IMap.end() && "Interval does not exist for stack slot");
+    return I->second;
+  }
+
+  bool hasInterval(int Slot) const { return S2IMap.count(Slot); }
+
+  const TargetRegisterClass *getIntervalRegClass(int Slot) const {
+    assert(Slot >= 0 && "Spill slot indice must be >= 0");
+    std::map<int, const TargetRegisterClass *>::const_iterator I =
+        S2RCMap.find(Slot);
+    assert(I != S2RCMap.end() &&
+           "Register class info does not exist for stack slot");
+    return I->second;
+  }
+
+  VNInfo::Allocator &getVNInfoAllocator() { return VNInfoAllocator; }
+
+  void getAnalysisUsage(AnalysisUsage &AU) const override;
+  void releaseMemory() override;
+
+  /// runOnMachineFunction - pass entry point
+  bool runOnMachineFunction(MachineFunction &) override;
+
+  /// print - Implement the dump method.
+  void print(raw_ostream &O, const Module * = nullptr) const override;
+};
+
+} // end namespace llvm
+
+#endif

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/MachineOperand.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/MachineOperand.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/MachineOperand.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -29,6 +29,7 @@ class GlobalValue;
 class MachineBasicBlock;
 class MachineInstr;
 class MachineRegisterInfo;
+class MCCFIInstruction;
 class MDNode;
 class ModuleSlotTracker;
 class TargetMachine;
@@ -249,6 +250,12 @@ class MachineOperand { (public)
   /// Print a stack object reference.
   static void printStackObjectReference(raw_ostream &OS, unsigned FrameIndex,
                                         bool IsFixed, StringRef Name);
+
+  /// Print the offset with explicit +/- signs.
+  static void printOperandOffset(raw_ostream &OS, int64_t Offset);
+
+  /// Print an IRSlotNumber.
+  static void printIRSlotNumber(raw_ostream &OS, int Slot);
 
   /// Print the MachineOperand to \p os.
   /// Providing a valid \p TRI and \p IntrinsicInfo results in a more

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/RuntimeLibcalls.def
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/RuntimeLibcalls.def	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/RuntimeLibcalls.def	Sun Dec 24 01:04:58 2017	(r327134)
@@ -165,6 +165,8 @@ HANDLE_LIBCALL(SINCOS_F64, nullptr)
 HANDLE_LIBCALL(SINCOS_F80, nullptr)
 HANDLE_LIBCALL(SINCOS_F128, nullptr)
 HANDLE_LIBCALL(SINCOS_PPCF128, nullptr)
+HANDLE_LIBCALL(SINCOS_STRET_F32, nullptr)
+HANDLE_LIBCALL(SINCOS_STRET_F64, nullptr)
 HANDLE_LIBCALL(POW_F32, "powf")
 HANDLE_LIBCALL(POW_F64, "pow")
 HANDLE_LIBCALL(POW_F80, "powl")
@@ -334,6 +336,7 @@ HANDLE_LIBCALL(O_PPCF128, "__gcc_qunord")
 HANDLE_LIBCALL(MEMCPY, "memcpy")
 HANDLE_LIBCALL(MEMMOVE, "memmove")
 HANDLE_LIBCALL(MEMSET, "memset")
+HANDLE_LIBCALL(BZERO, nullptr)
 
 // Element-wise unordered-atomic memory of different sizes
 HANDLE_LIBCALL(MEMCPY_ELEMENT_UNORDERED_ATOMIC_1, "__llvm_memcpy_element_unordered_atomic_1")

Copied: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SDNodeProperties.td (from r327133, vendor/llvm/dist/include/llvm/CodeGen/SDNodeProperties.td)
==============================================================================
--- /dev/null	00:00:00 1970	(empty, because file is newly added)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SDNodeProperties.td	Sun Dec 24 01:04:58 2017	(r327134, copy of r327133, vendor/llvm/dist/include/llvm/CodeGen/SDNodeProperties.td)
@@ -0,0 +1,34 @@
+//===- SDNodeProperties.td - Common code for DAG isels ---*- tablegen -*-===//
+//
+//                     The LLVM Compiler Infrastructure
+//
+// This file is distributed under the University of Illinois Open Source
+// License. See LICENSE.TXT for details.
+//
+//===----------------------------------------------------------------------===//
+
+class SDNodeProperty;
+
+// Selection DAG Pattern Operations
+class SDPatternOperator {
+  list<SDNodeProperty> Properties = [];
+}
+
+//===----------------------------------------------------------------------===//
+// Selection DAG Node Properties.
+//
+// Note: These are hard coded into tblgen.
+//
+def SDNPCommutative : SDNodeProperty;   // X op Y == Y op X
+def SDNPAssociative : SDNodeProperty;   // (X op Y) op Z == X op (Y op Z)
+def SDNPHasChain    : SDNodeProperty;   // R/W chain operand and result
+def SDNPOutGlue     : SDNodeProperty;   // Write a flag result
+def SDNPInGlue      : SDNodeProperty;   // Read a flag operand
+def SDNPOptInGlue   : SDNodeProperty;   // Optionally read a flag operand
+def SDNPMayStore    : SDNodeProperty;   // May write to memory, sets 'mayStore'.
+def SDNPMayLoad     : SDNodeProperty;   // May read memory, sets 'mayLoad'.
+def SDNPSideEffect  : SDNodeProperty;   // Sets 'HasUnmodelledSideEffects'.
+def SDNPMemOperand  : SDNodeProperty;   // Touches memory, has assoc MemOperand
+def SDNPVariadic    : SDNodeProperty;   // Node has variable arguments.
+def SDNPWantRoot    : SDNodeProperty;   // ComplexPattern gets the root of match
+def SDNPWantParent  : SDNodeProperty;   // ComplexPattern gets the parent

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SelectionDAGNodes.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SelectionDAGNodes.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/SelectionDAGNodes.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -189,8 +189,8 @@ class SDValue { (public)
   inline bool isUndef() const;
   inline unsigned getMachineOpcode() const;
   inline const DebugLoc &getDebugLoc() const;
-  inline void dump() const;
-  inline void dumpr() const;
+  inline void dump(const SelectionDAG *G = nullptr) const;
+  inline void dumpr(const SelectionDAG *G = nullptr) const;
 
   /// Return true if this operand (which must be a chain) reaches the
   /// specified operand without crossing any side-effecting instructions.
@@ -1089,12 +1089,12 @@ inline const DebugLoc &SDValue::getDebugLoc() const {
   return Node->getDebugLoc();
 }
 
-inline void SDValue::dump() const {
-  return Node->dump();
+inline void SDValue::dump(const SelectionDAG *G) const {
+  return Node->dump(G);
 }
 
-inline void SDValue::dumpr() const {
-  return Node->dumpr();
+inline void SDValue::dumpr(const SelectionDAG *G) const {
+  return Node->dumpr(G);
 }
 
 // Define inline functions from the SDUse class.

Modified: projects/clang600-import/contrib/llvm/include/llvm/CodeGen/TargetLowering.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/CodeGen/TargetLowering.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/CodeGen/TargetLowering.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -824,8 +824,8 @@ class TargetLoweringBase { (public)
   /// also combined within this function. Currently, the minimum size check is
   /// performed in findJumpTable() in SelectionDAGBuiler and
   /// getEstimatedNumberOfCaseClusters() in BasicTTIImpl.
-  bool isSuitableForJumpTable(const SwitchInst *SI, uint64_t NumCases,
-                              uint64_t Range) const {
+  virtual bool isSuitableForJumpTable(const SwitchInst *SI, uint64_t NumCases,
+                                      uint64_t Range) const {
     const bool OptForSize = SI->getParent()->getParent()->optForSize();
     const unsigned MinDensity = getMinimumJumpTableDensity(OptForSize);
     const unsigned MaxJumpTableSize =
@@ -1276,7 +1276,7 @@ class TargetLoweringBase { (public)
   }
 
   /// Return lower limit for number of blocks in a jump table.
-  unsigned getMinimumJumpTableEntries() const;
+  virtual unsigned getMinimumJumpTableEntries() const;
 
   /// Return lower limit of the density in a jump table.
   unsigned getMinimumJumpTableDensity(bool OptForSize) const;
@@ -2429,7 +2429,7 @@ class TargetLoweringBase { (public)
     PromoteToType;
 
   /// Stores the name each libcall.
-  const char *LibcallRoutineNames[RTLIB::UNKNOWN_LIBCALL];
+  const char *LibcallRoutineNames[RTLIB::UNKNOWN_LIBCALL + 1];
 
   /// The ISD::CondCode that should be used to test the result of each of the
   /// comparison libcall against zero.
@@ -2437,6 +2437,9 @@ class TargetLoweringBase { (public)
 
   /// Stores the CallingConv that should be used for each libcall.
   CallingConv::ID LibcallCallingConvs[RTLIB::UNKNOWN_LIBCALL];
+
+  /// Set default libcall names and calling conventions.
+  void InitLibcalls(const Triple &TT);
 
 protected:
   /// Return true if the extension represented by \p I is free.

Modified: projects/clang600-import/contrib/llvm/include/llvm/DebugInfo/DWARF/DWARFUnit.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/DebugInfo/DWARF/DWARFUnit.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/DebugInfo/DWARF/DWARFUnit.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -165,6 +165,29 @@ struct BaseAddress {
   uint64_t SectionIndex;
 };
 
+/// Represents a unit's contribution to the string offsets table.
+struct StrOffsetsContributionDescriptor {
+  uint64_t Base = 0;
+  uint64_t Size = 0;
+  /// Format and version.
+  DWARFFormParams FormParams = {0, 0, dwarf::DwarfFormat::DWARF32};
+
+  StrOffsetsContributionDescriptor(uint64_t Base, uint64_t Size,
+                                   uint8_t Version, dwarf::DwarfFormat Format)
+      : Base(Base), Size(Size), FormParams({Version, 0, Format}) {}
+
+  uint8_t getVersion() const { return FormParams.Version; }
+  dwarf::DwarfFormat getFormat() const { return FormParams.Format; }
+  uint8_t getDwarfOffsetByteSize() const {
+    return FormParams.getDwarfOffsetByteSize();
+  }
+  /// Determine whether a contribution to the string offsets table is
+  /// consistent with the relevant section size and that its length is
+  /// a multiple of the size of one of its entries.
+  Optional<StrOffsetsContributionDescriptor>
+  validateContributionSize(DWARFDataExtractor &DA);
+};
+
 class DWARFUnit {
   DWARFContext &Context;
   /// Section containing this DWARFUnit.
@@ -176,7 +199,6 @@ class DWARFUnit {
   const DWARFSection &LineSection;
   StringRef StringSection;
   const DWARFSection &StringOffsetSection;
-  uint64_t StringOffsetSectionBase = 0;
   const DWARFSection *AddrOffsetSection;
   uint32_t AddrOffsetSectionBase = 0;
   bool isLittleEndian;
@@ -185,6 +207,9 @@ class DWARFUnit {
 
   // Version, address size, and DWARF format.
   DWARFFormParams FormParams;
+  /// Start, length, and DWARF format of the unit's contribution to the string
+  /// offsets table (DWARF v5).
+  Optional<StrOffsetsContributionDescriptor> StringOffsetsTableContribution;
 
   uint32_t Offset;
   uint32_t Length;
@@ -195,11 +220,41 @@ class DWARFUnit {
   /// The compile unit debug information entry items.
   std::vector<DWARFDebugInfoEntry> DieArray;
 
-  /// Map from range's start address to end address and corresponding DIE.
-  /// IntervalMap does not support range removal, as a result, we use the
-  /// std::map::upper_bound for address range lookup.
-  std::map<uint64_t, std::pair<uint64_t, DWARFDie>> AddrDieMap;
+  /// The vector of inlined subroutine DIEs that we can map directly to from
+  /// their subprogram below.
+  std::vector<DWARFDie> InlinedSubroutineDIEs;
 
+  /// A type representing a subprogram DIE and a map (built using a sorted
+  /// vector) into that subprogram's inlined subroutine DIEs.
+  struct SubprogramDIEAddrInfo {
+    DWARFDie SubprogramDIE;
+
+    uint64_t SubprogramBasePC;
+
+    /// A vector sorted to allow mapping from a relative PC to the inlined
+    /// subroutine DIE with the most specific address range covering that PC.
+    ///
+    /// The PCs are relative to the `SubprogramBasePC`.
+    ///
+    /// The vector is sorted in ascending order of the first int which
+    /// represents the relative PC for an interval in the map. The second int
+    /// represents the index into the `InlinedSubroutineDIEs` vector of the DIE
+    /// that interval maps to. An index of '-1` indicates an empty mapping. The
+    /// interval covered is from the `.first` relative PC to the next entry's
+    /// `.first` relative PC.
+    std::vector<std::pair<uint32_t, int32_t>> InlinedSubroutineDIEAddrMap;
+  };
+
+  /// Vector of the subprogram DIEs and their subroutine address maps.
+  std::vector<SubprogramDIEAddrInfo> SubprogramDIEAddrInfos;
+
+  /// A vector sorted to allow mapping from a PC to the subprogram DIE (and
+  /// associated addr map) index. Subprograms with overlapping PC ranges aren't
+  /// supported here. Nothing will crash, but the mapping may be inaccurate.
+  /// This vector may also contain "empty" ranges marked by an address with
+  /// a DIE index of '-1'.
+  std::vector<std::pair<uint64_t, int64_t>> SubprogramDIEAddrMap;
+
   using die_iterator_range =
       iterator_range<std::vector<DWARFDebugInfoEntry>::iterator>;
 
@@ -219,6 +274,21 @@ class DWARFUnit {
   /// Size in bytes of the unit header.
   virtual uint32_t getHeaderSize() const { return getVersion() <= 4 ? 11 : 12; }
 
+  /// Find the unit's contribution to the string offsets table and determine its
+  /// length and form. The given offset is expected to be derived from the unit
+  /// DIE's DW_AT_str_offsets_base attribute.
+  Optional<StrOffsetsContributionDescriptor>
+  determineStringOffsetsTableContribution(DWARFDataExtractor &DA,
+                                          uint64_t Offset);
+
+  /// Find the unit's contribution to the string offsets table and determine its
+  /// length and form. The given offset is expected to be 0 in a dwo file or,
+  /// in a dwp file, the start of the unit's contribution to the string offsets
+  /// table section (as determined by the index table).
+  Optional<StrOffsetsContributionDescriptor>
+  determineStringOffsetsTableContributionDWO(DWARFDataExtractor &DA,
+                                             uint64_t Offset);
+
 public:
   DWARFUnit(DWARFContext &Context, const DWARFSection &Section,
             const DWARFDebugAbbrev *DA, const DWARFSection *RS, StringRef SS,
@@ -242,9 +312,6 @@ class DWARFUnit {
     AddrOffsetSectionBase = Base;
   }
 
-  /// Recursively update address to Die map.
-  void updateAddressDieMap(DWARFDie Die);
-
   void setRangesSection(const DWARFSection *RS, uint32_t Base) {
     RangeSection = RS;
     RangeSectionBase = Base;
@@ -272,6 +339,10 @@ class DWARFUnit {
   uint32_t getNextUnitOffset() const { return Offset + Length + 4; }
   uint32_t getLength() const { return Length; }
 
+  const Optional<StrOffsetsContributionDescriptor> &
+  getStringOffsetsTableContribution() const {
+    return StringOffsetsTableContribution;
+  }
   const DWARFFormParams &getFormParams() const { return FormParams; }
   uint16_t getVersion() const { return FormParams.Version; }
   dwarf::DwarfFormat getFormat() const { return FormParams.Format; }
@@ -281,6 +352,16 @@ class DWARFUnit {
     return FormParams.getDwarfOffsetByteSize();
   }
 
+  uint8_t getDwarfStringOffsetsByteSize() const {
+    assert(StringOffsetsTableContribution);
+    return StringOffsetsTableContribution->getDwarfOffsetByteSize();
+  }
+
+  uint64_t getStringOffsetsBase() const {
+    assert(StringOffsetsTableContribution);
+    return StringOffsetsTableContribution->Base;
+  }
+
   const DWARFAbbreviationDeclarationSet *getAbbreviations() const;
 
   uint8_t getUnitType() const { return UnitType; }
@@ -426,6 +507,9 @@ class DWARFUnit {
   /// parseDWO - Parses .dwo file for current compile unit. Returns true if
   /// it was actually constructed.
   bool parseDWO();
+
+  void buildSubprogramDIEAddrMap();
+  void buildInlinedSubroutineDIEAddrMap(SubprogramDIEAddrInfo &SPInfo);
 };
 
 } // end namespace llvm

Modified: projects/clang600-import/contrib/llvm/include/llvm/FuzzMutate/IRMutator.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/FuzzMutate/IRMutator.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/FuzzMutate/IRMutator.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -16,6 +16,7 @@
 #ifndef LLVM_FUZZMUTATE_IRMUTATOR_H
 #define LLVM_FUZZMUTATE_IRMUTATOR_H
 
+#include "llvm/ADT/Optional.h"
 #include "llvm/FuzzMutate/OpDescriptor.h"
 #include "llvm/Support/ErrorHandling.h"
 
@@ -74,7 +75,8 @@ class IRMutator { (public)
 class InjectorIRStrategy : public IRMutationStrategy {
   std::vector<fuzzerop::OpDescriptor> Operations;
 
-  fuzzerop::OpDescriptor chooseOperation(Value *Src, RandomIRBuilder &IB);
+  Optional<fuzzerop::OpDescriptor> chooseOperation(Value *Src,
+                                                   RandomIRBuilder &IB);
 
 public:
   InjectorIRStrategy(std::vector<fuzzerop::OpDescriptor> &&Operations)

Modified: projects/clang600-import/contrib/llvm/include/llvm/IR/Function.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/IR/Function.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/IR/Function.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -248,6 +248,12 @@ class Function : public GlobalObject, public ilist_nod
   /// pgo data.
   Optional<uint64_t> getEntryCount() const;
 
+  /// Return true if the function is annotated with profile data.
+  ///
+  /// Presence of entry counts from a profile run implies the function has
+  /// profile annotations.
+  bool hasProfileData() const { return getEntryCount().hasValue(); }
+
   /// Returns the set of GUIDs that needs to be imported to the function for
   /// sample PGO, to enable the same inlines as the profiled optimized binary.
   DenseSet<GlobalValue::GUID> getImportGUIDs() const;

Modified: projects/clang600-import/contrib/llvm/include/llvm/IR/Intrinsics.td
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/IR/Intrinsics.td	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/IR/Intrinsics.td	Sun Dec 24 01:04:58 2017	(r327134)
@@ -12,6 +12,7 @@
 //===----------------------------------------------------------------------===//
 
 include "llvm/CodeGen/ValueTypes.td"
+include "llvm/CodeGen/SDNodeProperties.td"
 
 //===----------------------------------------------------------------------===//
 //  Properties we keep track of for intrinsics.
@@ -264,16 +265,17 @@ def llvm_vararg_ty     : LLVMType<isVoid>;   // this m
 //    intrinsic.
 //  * Properties can be set to describe the behavior of the intrinsic.
 //
-class SDPatternOperator;
 class Intrinsic<list<LLVMType> ret_types,
                 list<LLVMType> param_types = [],
-                list<IntrinsicProperty> properties = [],
-                string name = ""> : SDPatternOperator {
+                list<IntrinsicProperty> intr_properties = [],
+                string name = "",
+                list<SDNodeProperty> sd_properties = []> : SDPatternOperator {
   string LLVMName = name;
   string TargetPrefix = "";   // Set to a prefix for target-specific intrinsics.
   list<LLVMType> RetTypes = ret_types;
   list<LLVMType> ParamTypes = param_types;
-  list<IntrinsicProperty> IntrProperties = properties;
+  list<IntrinsicProperty> IntrProperties = intr_properties;
+  let Properties = sd_properties;
 
   bit isTarget = 0;
 }

Modified: projects/clang600-import/contrib/llvm/include/llvm/LTO/legacy/ThinLTOCodeGenerator.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/LTO/legacy/ThinLTOCodeGenerator.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/LTO/legacy/ThinLTOCodeGenerator.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -148,10 +148,14 @@ class ThinLTOCodeGenerator { (public)
   /// incremental build.
   void setCacheDir(std::string Path) { CacheOptions.Path = std::move(Path); }
 
-  /// Cache policy: interval (seconds) between two prune of the cache. Set to a
-  /// negative value (default) to disable pruning. A value of 0 will be ignored.
+  /// Cache policy: interval (seconds) between two prunes of the cache. Set to a
+  /// negative value to disable pruning. A value of 0 will be ignored.
   void setCachePruningInterval(int Interval) {
-    if (Interval)
+    if (Interval == 0)
+      return;
+    if(Interval < 0)
+      CacheOptions.Policy.Interval.reset();
+    else
       CacheOptions.Policy.Interval = std::chrono::seconds(Interval);
   }
 

Modified: projects/clang600-import/contrib/llvm/include/llvm/MC/MCAsmInfo.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/MC/MCAsmInfo.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/MC/MCAsmInfo.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -165,7 +165,8 @@ class MCAsmInfo { (protected)
   const char *ZeroDirective;
 
   /// This directive allows emission of an ascii string with the standard C
-  /// escape characters embedded into it.  Defaults to "\t.ascii\t"
+  /// escape characters embedded into it.  If a target doesn't support this, it
+  /// can be set to null. Defaults to "\t.ascii\t"
   const char *AsciiDirective;
 
   /// If not null, this allows for special handling of zero terminated strings

Modified: projects/clang600-import/contrib/llvm/include/llvm/MC/MCStreamer.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/MC/MCStreamer.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/MC/MCStreamer.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -95,6 +95,17 @@ class MCTargetStreamer { (public)
   virtual void prettyPrintAsm(MCInstPrinter &InstPrinter, raw_ostream &OS,
                               const MCInst &Inst, const MCSubtargetInfo &STI);
 
+  virtual void emitDwarfFileDirective(StringRef Directive);
+
+  /// Update streamer for a new active section.
+  ///
+  /// This is called by PopSection and SwitchSection, if the current
+  /// section changes.
+  virtual void changeSection(const MCSection *CurSection, MCSection *Section,
+                             const MCExpr *SubSection, raw_ostream &OS);
+
+  virtual void emitValue(const MCExpr *Value);
+
   virtual void finish();
 };
 

Modified: projects/clang600-import/contrib/llvm/include/llvm/Object/Wasm.h
==============================================================================
--- projects/clang600-import/contrib/llvm/include/llvm/Object/Wasm.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Object/Wasm.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -43,9 +43,9 @@ class WasmSymbol { (public)
   };
 
   WasmSymbol(StringRef Name, SymbolType Type, uint32_t Section,
-             uint32_t ElementIndex, uint32_t ImportIndex = 0)
+             uint32_t ElementIndex, uint32_t FunctionType = 0)
       : Name(Name), Type(Type), Section(Section), ElementIndex(ElementIndex),
-        ImportIndex(ImportIndex) {}
+        FunctionType(FunctionType) {}
 
   StringRef Name;
   SymbolType Type;
@@ -55,9 +55,19 @@ class WasmSymbol { (public)
   // Index into either the function or global index space.
   uint32_t ElementIndex;
 

*** DIFF OUTPUT TRUNCATED AT 1000 LINES ***



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201712240104.vBO14xC8078238>
--- projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysis.h	Sun Dec 24 01:01:08 2017	(r327133)
+++ projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysis.h	Sun Dec 24 01:04:58 2017	(r327134)
@@ -95,46 +95,81 @@ enum AliasResult {
 ///
 /// This is no access at all, a modification, a reference, or both
 /// a modification and a reference. These are specifically structured such that
 /// they form a two bit matrix and bit-tests for 'mod' or 'ref'
 /// work with any of the possible values.
-
 enum class ModRefInfo {
+  /// Must is provided for completeness, but no routines will return only
+  /// Must today. See definition of Must below.
+  Must = 0,
+  /// The access may reference the value stored in memory,
+  /// a mustAlias relation was found, and no mayAlias or partialAlias found.
+  MustRef = 1,
+  /// The access may modify the value stored in memory,
+  /// a mustAlias relation was found, and no mayAlias or partialAlias found.
+  MustMod = 2,
+  /// The access may reference, modify or both the value stored in memory,
+  /// a mustAlias relation was found, and no mayAlias or partialAlias found.
+  MustModRef = MustRef | MustMod,
   /// The access neither references nor modifies the value stored in memory.
-  NoModRef = 0,
+  NoModRef = 4,
   /// The access may reference the value stored in memory.
-  Ref = 1,
+  Ref = NoModRef | MustRef,
   /// The access may modify the value stored in memory.
-  Mod = 2,
+  Mod = NoModRef | MustMod,
   /// The access may reference and may modify the value stored in memory.
   ModRef = Ref | Mod,
+
+  /// About Must:
+  /// Must is set in a best effort manner.
+  /// We usually do not try our best to infer Must, instead it is merely
+  /// another piece of "free" information that is presented when available.
+  /// Must set means there was certainly a MustAlias found. For calls,
+  /// where multiple arguments are checked (argmemonly), this translates to
+  /// only MustAlias or NoAlias was found.
+  /// Must is not set for RAR accesses, even if the two locations must
+  /// alias. The reason is that two read accesses translate to an early return
+  /// of NoModRef. An additional alias check to set Must may be
+  /// expensive. Other cases may also not set Must(e.g. callCapturesBefore).
+  /// We refer to Must being *set* when the most significant bit is *cleared*.
+  /// Conversely we *clear* Must information by *setting* the Must bit to 1.
 };
 
 LLVM_NODISCARD inline bool isNoModRef(const ModRefInfo MRI) {
-  return MRI == ModRefInfo::NoModRef;
+  return (static_cast<int>(MRI) & static_cast<int>(ModRefInfo::MustModRef)) ==
+         static_cast<int>(ModRefInfo::Must);
 }
 LLVM_NODISCARD inline bool isModOrRefSet(const ModRefInfo MRI) {
-  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::ModRef);
+  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::MustModRef);
 }
 LLVM_NODISCARD inline bool isModAndRefSet(const ModRefInfo MRI) {
-  return (static_cast<int>(MRI) & static_cast<int>(ModRefInfo::ModRef)) ==
-         static_cast<int>(ModRefInfo::ModRef);
+  return (static_cast<int>(MRI) & static_cast<int>(ModRefInfo::MustModRef)) ==
+         static_cast<int>(ModRefInfo::MustModRef);
 }
 LLVM_NODISCARD inline bool isModSet(const ModRefInfo MRI) {
-  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::Mod);
+  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::MustMod);
 }
 LLVM_NODISCARD inline bool isRefSet(const ModRefInfo MRI) {
-  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::Ref);
+  return static_cast<int>(MRI) & static_cast<int>(ModRefInfo::MustRef);
 }
+LLVM_NODISCARD inline bool isMustSet(const ModRefInfo MRI) {
+  return !(static_cast<int>(MRI) & static_cast<int>(ModRefInfo::NoModRef));
+}
 
 LLVM_NODISCARD inline ModRefInfo setMod(const ModRefInfo MRI) {
-  return ModRefInfo(static_cast<int>(MRI) | static_cast<int>(ModRefInfo::Mod));
+  return ModRefInfo(static_cast<int>(MRI) |
+                    static_cast<int>(ModRefInfo::MustMod));
 }
 LLVM_NODISCARD inline ModRefInfo setRef(const ModRefInfo MRI) {
-  return ModRefInfo(static_cast<int>(MRI) | static_cast<int>(ModRefInfo::Ref));
+  return ModRefInfo(static_cast<int>(MRI) |
+                    static_cast<int>(ModRefInfo::MustRef));
 }
+LLVM_NODISCARD inline ModRefInfo setMust(const ModRefInfo MRI) {
+  return ModRefInfo(static_cast<int>(MRI) &
+                    static_cast<int>(ModRefInfo::MustModRef));
+}
 LLVM_NODISCARD inline ModRefInfo setModAndRef(const ModRefInfo MRI) {
   return ModRefInfo(static_cast<int>(MRI) |
-                    static_cast<int>(ModRefInfo::ModRef));
+                    static_cast<int>(ModRefInfo::MustModRef));
 }
 LLVM_NODISCARD inline ModRefInfo clearMod(const ModRefInfo MRI) {
   return ModRefInfo(static_cast<int>(MRI) & static_cast<int>(ModRefInfo::Ref));
@@ -142,6 +177,10 @@ LLVM_NODISCARD inline ModRefInfo clearMod(const ModRef
 LLVM_NODISCARD inline ModRefInfo clearRef(const ModRefInfo MRI) {
   return ModRefInfo(static_cast<int>(MRI) & static_cast<int>(ModRefInfo::Mod));
 }
+LLVM_NODISCARD inline ModRefInfo clearMust(const ModRefInfo MRI) {
+  return ModRefInfo(static_cast<int>(MRI) |
+                    static_cast<int>(ModRefInfo::NoModRef));
+}
 LLVM_NODISCARD inline ModRefInfo unionModRef(const ModRefInfo MRI1,
                                              const ModRefInfo MRI2) {
   return ModRefInfo(static_cast<int>(MRI1) | static_cast<int>(MRI2));
@@ -160,11 +199,11 @@ enum FunctionModRefLocation {
   /// Base case is no access to memory.
   FMRL_Nowhere = 0,
   /// Access to memory via argument pointers.
-  FMRL_ArgumentPointees = 4,
+  FMRL_ArgumentPointees = 8,
   /// Memory that is inaccessible via LLVM IR.
-  FMRL_InaccessibleMem = 8,
+  FMRL_InaccessibleMem = 16,
   /// Access to any memory.
-  FMRL_Anywhere = 16 | FMRL_InaccessibleMem | FMRL_ArgumentPointees
+  FMRL_Anywhere = 32 | FMRL_InaccessibleMem | FMRL_ArgumentPointees
 };
 
 /// Summary of how a function affects memory in the program.
@@ -344,7 +383,7 @@ class AAResults { (public)
   /// result's bits are set to indicate the allowed aliasing ModRef kinds. Note
   /// that these bits do not necessarily account for the overall behavior of
   /// the function, but rather only provide additional per-argument
-  /// information.
+  /// information. This never sets ModRefInfo::Must.
   ModRefInfo getArgModRefInfo(ImmutableCallSite CS, unsigned ArgIdx);
 
   /// Return the behavior of the given call site.
@@ -624,6 +663,8 @@ class AAResults { (public)
   /// or reads the specified memory location \p MemLoc before instruction \p I
   /// in a BasicBlock. An ordered basic block \p OBB can be used to speed up
   /// instruction ordering queries inside the BasicBlock containing \p I.
+  /// Early exits in callCapturesBefore may lead to ModRefInfo::Must not being
+  /// set.
   ModRefInfo callCapturesBefore(const Instruction *I,
                                 const MemoryLocation &MemLoc, DominatorTree *DT,
                                 OrderedBasicBlock *OBB = nullptr);
@@ -95,46 +95,81 @@ enum AliasResult {
 /// This is no access at all, a modification, a reference, or both
 /// a modification and a reference. These are specifically structured such that
-/// they form a two bit matrix and bit-tests for 'mod' or 'ref'
+/// they form a three bit matrix and bit-tests for 'mod' or 'ref' or 'must'
 /// work with any of the possible values.

Modified: projects/clang600-import/contrib/llvm/include/llvm/Analysis/AliasAnalysisEvaluator.h
==============================================================================